.. SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Python API
==========


Version
*******
.. automodule:: pypdfium2._version


Opener
******
.. automodule:: pypdfium2._helpers.classes
    :special-members: __len__
.. automodule:: pypdfium2._helpers.opener
    :exclude-members: open_pdf_auto, close_pdf

Saver
*****
.. automodule:: pypdfium2._helpers.saver

Page Renderer
*************
.. automodule:: pypdfium2._helpers.page_renderer

Document Renderer
*****************
.. automodule:: pypdfium2._helpers.pdf_renderer

Text Inserter
*************
.. automodule:: pypdfium2._helpers.text_inserter

Text Extractor
**************
.. versionadded:: 1.10.0
.. automodule:: pypdfium2._helpers.text_extractor

Page Objects
************
.. versionadded:: 1.10.0
.. automodule:: pypdfium2._helpers.pageobjects

TOC Parser
**********
.. automodule:: pypdfium2._helpers.toc

PDF Boxes
*********
.. automodule:: pypdfium2._helpers.boxes

Error Handler
*************
.. automodule:: pypdfium2._helpers.error_handler


Constants
*********

.. automodule:: pypdfium2._helpers.constants
